@@ -242,6 +242,13 @@ class TestOvnProviderDriver(ovn_base.TestOvnOctaviaBase):
         self.ref_member.address = 'fc00::1'
         self.assertTrue(self.driver._ip_version_differs(self.ref_member))
 
+    def test__ip_version_differs_lb_not_found(self):
+        self.mock_find_ovn_lb_by_pool_id = mock.patch.object(
+            ovn_helper.OvnProviderHelper,
+            '_find_ovn_lb_by_pool_id').start()
+        self.mock_find_ovn_lb_by_pool_id.return_value = (_, None)
+        self.assertFalse(self.driver._ip_version_differs(self.ref_member))
+
     def test__ip_version_differs_pool_disabled(self):
         self.mock_find_lb_pool_key.side_effect = [None, self.ovn_lb]
         self.driver._ip_version_differs(self.ref_member)
@@ -323,6 +330,10 @@ class TestOvnProviderDriver(ovn_base.TestOvnOctaviaBase):
         member.subnet_id = None
         self._test_member_create(member)
 
+    def test__check_monitor_options_member_no_monitor_data(self):
+        self.ref_member.monitor_address = None
+        self.assertFalse(self.driver._check_monitor_options(self.ref_member))
+
     def test_member_create_monitor_opts(self):
         self.ref_member.monitor_address = '172.20.20.1'
         self.assertRaises(exceptions.UnsupportedOptionError,
@@ -355,7 +366,8 @@ class TestOvnProviderDriver(ovn_base.TestOvnOctaviaBase):
                 'protocol_port': self.ref_member.protocol_port,
                 'pool_id': self.ref_member.pool_id,
                 'admin_state_up': self.update_member.admin_state_up,
-                'old_admin_state_up': self.ref_member.admin_state_up}
+                'old_admin_state_up': self.ref_member.admin_state_up,
+                'subnet_id': self.ref_member.subnet_id}
         expected_dict = {'type': ovn_const.REQ_TYPE_MEMBER_UPDATE,
                          'info': info}
         self.driver.member_update(self.ref_member, self.update_member)
@@ -369,7 +381,8 @@ class TestOvnProviderDriver(ovn_base.TestOvnOctaviaBase):
                 'protocol_port': self.ref_member.protocol_port,
                 'pool_id': self.ref_member.pool_id,
                 'admin_state_up': self.update_member.admin_state_up,
-                'old_admin_state_up': self.ref_member.admin_state_up}
+                'old_admin_state_up': self.ref_member.admin_state_up,
+                'subnet_id': self.ref_member.subnet_id}
         expected_dict = {'type': ovn_const.REQ_TYPE_MEMBER_UPDATE,
                          'info': info}
         member = copy.copy(self.ref_member)
@@ -385,7 +398,8 @@ class TestOvnProviderDriver(ovn_base.TestOvnOctaviaBase):
                 'address': self.ref_member.address,
                 'protocol_port': self.ref_member.protocol_port,
                 'pool_id': self.ref_member.pool_id,
-                'old_admin_state_up': self.ref_member.admin_state_up}
+                'old_admin_state_up': self.ref_member.admin_state_up,
+                'subnet_id': self.ref_member.subnet_id}
         expected_dict = {'type': ovn_const.REQ_TYPE_MEMBER_UPDATE,
                          'info': info}
         member = copy.copy(self.ref_member)
@@ -393,6 +407,15 @@ class TestOvnProviderDriver(ovn_base.TestOvnOctaviaBase):
         self.driver.member_update(member, self.update_member)
         self.mock_add_request.assert_called_once_with(expected_dict)
 
+    def test_member_update_missing_subnet_id_differs_from_lb_vip(self):
+        self.driver._ovn_helper._get_subnet_from_pool.return_value = (
+            self.ref_member.subnet_id, '198.52.100.0/24')
+        self.driver._ovn_helper._check_ip_in_subnet.return_value = False
+        self.ref_member.subnet_id = data_models.UnsetType()
+        self.assertRaises(exceptions.UnsupportedOptionError,
+                          self.driver.member_update, self.ref_member,
+                          self.update_member)
+
     @mock.patch.object(ovn_driver.OvnProviderDriver, '_ip_version_differs')
     def test_member_update_no_ip_addr(self, mock_ip_differs):
         self.update_member.address = None
@@ -404,22 +427,6 @@ class TestOvnProviderDriver(ovn_base.TestOvnOctaviaBase):
                                         [self.ref_member, self.update_member])
         self.assertEqual(self.mock_add_request.call_count, 3)
 
-    def test_member_batch_update_member_delete(self):
-        info_md = {
-            'id': self.ref_member.member_id,
-            'address': mock.ANY,
-            'protocol_port': mock.ANY,
-            'pool_id': self.ref_member.pool_id,
-            'subnet_id': self.ref_member.subnet_id}
-        expected_dict_md = {
-            'type': ovn_const.REQ_TYPE_MEMBER_DELETE,
-            'info': info_md}
-        expected = [
-            mock.call(expected_dict_md)]
-        self.driver.member_batch_update(self.pool_id, [])
-        self.assertEqual(self.mock_add_request.call_count, 1)
-        self.mock_add_request.assert_has_calls(expected)
-
     def test_member_batch_update_no_members(self):
         pool_key = 'pool_%s' % self.pool_id
         ovn_lb = copy.copy(self.ovn_lb)
@@ -448,26 +455,6 @@ class TestOvnProviderDriver(ovn_base.TestOvnOctaviaBase):
         self.driver.member_batch_update(self.pool_id, [self.ref_member])
         self.assertEqual(self.mock_add_request.call_count, 2)
 
-    def test_member_batch_update_toggle_admin_state_up(self):
-        info_mu = {
-            'id': self.ref_member.member_id,
-            'address': self.member_address,
-            'protocol_port': self.member_port,
-            'pool_id': self.ref_member.pool_id,
-            'subnet_id': self.ref_member.subnet_id,
-            'admin_state_up': False}
-        expected_dict_mu = {
-            'type': ovn_const.REQ_TYPE_MEMBER_UPDATE,
-            'info': info_mu}
-        expected = [
-            mock.call(expected_dict_mu)]
-        self.ref_member.admin_state_up = False
-        self.ref_member.address = self.member_address
-        self.ref_member.protocol_port = self.member_port
-        self.driver.member_batch_update(self.pool_id, [self.ref_member])
-        self.assertEqual(self.mock_add_request.call_count, 1)
-        self.mock_add_request.assert_has_calls(expected)
-
     def test_member_batch_update_missing_subnet_id(self):
         self.ref_member.subnet_id = None
         self.assertRaises(exceptions.UnsupportedOptionError,
@@ -551,6 +538,14 @@ class TestOvnProviderDriver(ovn_base.TestOvnOctaviaBase):
             mock.call(expected_dict_dvr)]
         self.mock_add_request.assert_has_calls(expected)
 
+    def test_member_delete_missing_subnet_id_differs_from_lb_vip(self):
+        self.driver._ovn_helper._get_subnet_from_pool.return_value = (
+            self.ref_member.subnet_id, '198.52.100.0/24')
+        self.driver._ovn_helper._check_ip_in_subnet.return_value = False
+        self.ref_member.subnet_id = data_models.UnsetType()
+        self.assertRaises(exceptions.UnsupportedOptionError,
+                          self.driver.member_delete, self.ref_member)
+
     def test_listener_create(self):
         info = {'id': self.ref_listener.listener_id,
                 'protocol': self.ref_listener.protocol,
